==> open_watcom_1.5.0-src.zip: bld/wl/h/cmdelf.h <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  WHEN YOU FIGURE OUT WHAT THIS FILE DOES, PLEASE
*               DESCRIBE IT HERE!
*
****************************************************************************/


extern bool     ProcELF( void );
extern bool     ProcELFDLL( void );
extern bool     ProcELFImport( void );
extern bool     ProcELFAlignment( void );

extern void     SetELFFmt( void );
extern void     FreeELFFmt( void );
extern void     SetELFImportSymbol( symbol * );

extern bool     ProcExtraSections( void );
extern bool     ProcExportAll( void );

extern bool     ProcELFNoRelocs( void );

==> open_watcom_1.7.1-src.zip: bld/wl/h/cmdelf.h <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  ELF command line parsing function prototypes.
*
****************************************************************************/


extern bool     ProcELF( void );
extern bool     ProcELFDLL( void );
extern bool     ProcELFImport( void );
extern bool     ProcELFAlignment( void );

extern void     SetELFFmt( void );
extern void     FreeELFFmt( void );
extern void     SetELFImportSymbol( symbol * );

extern bool     ProcExtraSections( void );
extern bool     ProcExportAll( void );

extern bool     ProcELFNoRelocs( void );

extern bool     ProcELFRNumber( void );
extern bool     ProcELFRSVR4( void );
extern bool     ProcELFRNetBSD( void );
extern bool     ProcELFRLinux( void );
extern bool     ProcELFRSolrs( void );
extern bool     ProcELFRFBSD( void );
